<?xml version="1.0" encoding="UTF-8"?>
<!-- =======================================================================
XRadar
Copyright (c) 2004, 2005, Kristoffer Kvam
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
Neither the name of Kristoffer Kvam nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

See licence.txt for dependancies to other open projects.
======================================================================= -->
<xsl:stylesheet
 version="1.0"
 xmlns="http://www.w3.org/2000/svg"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:xlink="http://www.w3.org/1999/xlink"
 xmlns:xalan="http://xml.apache.org/xalan">

<xsl:import href="xradar://stylesheets/radar/graph/common-graph.xsl"/>
<xsl:import href="xradar://stylesheets/radar/graph/common-scripts.xsl"/>

<xsl:template name="abstractness-instability-graph">
  <xsl:param name="text-x-axis"/>
  <xsl:param name="text-y-axis"/>
  <xsl:param name="width"/>
  <xsl:param name="height"/>
  <xsl:param name="point-nodeset"/>
  <xsl:param name="y-axis-justification"/>

	<xsl:variable   name="color-ok"    select="$radar-config-doc/radar-config/defined-metrics/thresholds/threshold[@level = 3]/@color"/>
	<xsl:variable   name="color-warn"    select="$radar-config-doc/radar-config/defined-metrics/thresholds/threshold[@level = 2]/@color"/>
	<xsl:variable   name="color-ko"    select="$radar-config-doc/radar-config/defined-metrics/thresholds/threshold[@level = 1]/@color"/>


	<svg viewBox="0 0 {$width} {$height}" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">

		<xsl:variable name="pointset" select="xalan:nodeset($point-nodeset)"/>

		<xsl:call-template name="common-scripts"/>
		<!-- Include common features -->
		<xsl:call-template name="common-graph">
		  	<xsl:with-param name="text-x-axis" select="$text-x-axis"/>
		  	<xsl:with-param name="text-y-axis" select="$text-y-axis"/>
		  	<xsl:with-param name="width" select="$width"/>
			<xsl:with-param name="height" select="$height"/>
		</xsl:call-template>

		<g>
			<xsl:attribute name="stroke"><xsl:value-of select="$color-ko"/></xsl:attribute>
		    <line x1="{$width * 0.10}" y1="{$height * 0.20}" x2="{$width * 0.80}" y2="{$height * 0.90}"
		            stroke-width="{$width * 0.005}" />
		    <line x1="{$width * 0.10}" y1="{$height * 0.35}" x2="{$width * 0.65}" y2="{$height * 0.90}"
		            stroke-dasharray="20 10" stroke-width="{$width * 0.0025}" />
		     <line x1="{$width * 0.25}" y1="{$height * 0.20}" x2="{$width * 0.80}" y2="{$height * 0.75}"
		            stroke-dasharray="20 10" stroke-width="{$width * 0.0025}" />
	  	</g>

		<xsl:for-each select="$pointset/points/point">
	  		<xsl:call-template name="draw-point-on-graph">
		  		<xsl:with-param name="width" select="$width"/>
				<xsl:with-param name="height" select="$height"/>
				<xsl:with-param name="max-x" select="'1'"/>
				<xsl:with-param name="min-x" select="'0'"/>
				<xsl:with-param name="max-y" select="'1'"/>
				<xsl:with-param name="min-y" select="'0'"/>
				<xsl:with-param name="point" select="current()"/>
			</xsl:call-template>
	  	</xsl:for-each>

	  	<xsl:for-each select="$pointset/points/point">
	  		<xsl:call-template name="draw-label-on-graph">
		  		<xsl:with-param name="width" select="$width"/>
				<xsl:with-param name="height" select="$height"/>
				<xsl:with-param name="max-x" select="'1'"/>
				<xsl:with-param name="min-x" select="'0'"/>
				<xsl:with-param name="max-y" select="'1'"/>
				<xsl:with-param name="min-y" select="'0'"/>
				<xsl:with-param name="point" select="current()"/>
			</xsl:call-template>
	  	</xsl:for-each>

	</svg>

</xsl:template>

<xsl:template name="draw-point-on-graph">
	<xsl:param name="width"/>
	<xsl:param name="height"/>
	<xsl:param name="max-x"/>
	<xsl:param name="max-y"/>
	<xsl:param name="y-axis-justification"/>
	<xsl:param name="point"/>

	<xsl:variable name="id" select="concat($point/instability,'_',$point/abstractness)"/>

	<a xlink:href="{$point/link}">
		<circle
			fill="$color-ok" stroke="$color-ok" stroke-width="1"
	     onmouseover="onEvent(evt, '{$id}', 'visible');" onmouseout="onEvent(evt, '{$id}', 'hidden');">
		<xsl:attribute name="r">
			<xsl:value-of select="0.004*$width"/>
		</xsl:attribute>
		<xsl:attribute name="cx">
			<xsl:value-of select="$width * 0.10 + $width * 0.70 * $point/instability div $max-x"/>
		</xsl:attribute>
		<xsl:attribute name="cy">
			<xsl:value-of select="$height * 0.90 - $height * 0.70 * $point/abstractness div $max-y"/>
		</xsl:attribute>
	</circle>
	</a>
</xsl:template>


<xsl:template name="draw-label-on-graph">
	<xsl:param name="width"/>
	<xsl:param name="height"/>
	<xsl:param name="max-x"/>
	<xsl:param name="max-y"/>
	<xsl:param name="y-axis-justification"/>
	<xsl:param name="point"/>

	<xsl:variable name="id" select="concat($point/instability,'_',$point/abstractness)"/>
	<xsl:variable name="x" select="$width * 0.10 + $width * 0.70 * $point/instability div $max-x"/>
	<xsl:variable name="y" select="$height * 0.90 - $height * 0.70 * $point/abstractness div $max-y"/>

	<xsl:variable   name="color-ok"    select="$radar-config-doc/radar-config/defined-metrics/thresholds/threshold[@level = 3]/@color"/>
	<xsl:variable   name="color-warn"    select="$radar-config-doc/radar-config/defined-metrics/thresholds/threshold[@level = 2]/@color"/>
	<xsl:variable   name="color-ko"    select="$radar-config-doc/radar-config/defined-metrics/thresholds/threshold[@level = 1]/@color"/>


	<g style="visibility:hidden;">
		<xsl:attribute name="id"><xsl:value-of select="$id"/></xsl:attribute>
			<circle>
				<xsl:attribute name="style">fill:none;stroke:<xsl:value-of select="$color-ko"/>;stroke-width:1;</xsl:attribute>

			<xsl:attribute name="r">
				<xsl:value-of select="0.025*$width"/>
			</xsl:attribute>
			<xsl:attribute name="cx">
				<xsl:value-of select="$x"/>
			</xsl:attribute>
			<xsl:attribute name="cy">
				<xsl:value-of select="$y"/>
			</xsl:attribute>
		</circle>

		<text font-family="Verdana" fill="black">
	    	<xsl:attribute name="font-size">
    			<xsl:value-of select="ceiling($width * 0.023)"/>
	    	</xsl:attribute>
	    	<xsl:attribute name="style">text-anchor:<xsl:choose><xsl:when test="$point/instability div $max-x &lt; 0.3">start</xsl:when><xsl:when test="$point/instability div $max-x &gt; 0.7">end</xsl:when><xsl:otherwise>middle</xsl:otherwise></xsl:choose>;</xsl:attribute>
	    	<xsl:attribute name="x">
    			<xsl:value-of select="$x"/>
	    	</xsl:attribute>
	    	<xsl:attribute name="y">
		    	<xsl:value-of select="$y - $height * 0.04"/>
	    	</xsl:attribute>
	    	<xsl:value-of select="$point/label"/>
		</text>

		<text font-family="Verdana" fill="black">
	    	<xsl:attribute name="font-size">
    			<xsl:value-of select="ceiling($width * 0.023)"/>
	    	</xsl:attribute>
	    	<xsl:attribute name="x">
    			<xsl:value-of select="$width * 0.70"/>
	    	</xsl:attribute>
	    	<xsl:attribute name="y">
		    	<xsl:value-of select="$height * 0.04"/>
	    	</xsl:attribute>
	    	<xsl:value-of select="concat('Abstractness (A) : ',$point/abstractness)"/>
		</text>

		<text font-family="Verdana" fill="black">
	    	<xsl:attribute name="font-size">
    			<xsl:value-of select="ceiling($width * 0.023)"/>
	    	</xsl:attribute>
	    	<xsl:attribute name="x">
    			<xsl:value-of select="$width * 0.70"/>
	    	</xsl:attribute>
	    	<xsl:attribute name="y">
		    	<xsl:value-of select="$height * 0.07"/>
	    	</xsl:attribute>
	    	<xsl:value-of select="concat('Instability (I) : ',$point/instability)"/>
		</text>

		<text font-family="Verdana" fill="black">
	    	<xsl:attribute name="font-size">
    			<xsl:value-of select="ceiling($width * 0.023)"/>
	    	</xsl:attribute>
	    	<xsl:attribute name="x">
    			<xsl:value-of select="$width * 0.70"/>
	    	</xsl:attribute>
	    	<xsl:attribute name="y">
		    	<xsl:value-of select="$height * 0.1"/>
	    	</xsl:attribute>
	    	<xsl:value-of select="concat('Distance (D) : ',$point/distance)"/>
		</text>
	</g>
</xsl:template>


</xsl:stylesheet>
